[← Back to Response Metadata index](index.md)

# Common keys
Key | Default | Effect |
--- | --- | --- |
API_DUMP_HYBRID_PROPERTIES | True | Include SQLAlchemy hybrid properties |
API_DUMP_DATETIME | True | Add datetime timestamp |
API_DUMP_VERSION | True | Add api_version |
API_DUMP_STATUS_CODE | True | Add status_code |
API_DUMP_RESPONSE_MS | True | Add response_ms elapsed time |
API_DUMP_TOTAL_COUNT | True | Add total_count on collections |
API_DUMP_REQUEST_ID | False | Add request_id (also sent via header) |
API_DUMP_NULL_NEXT_URL | True | Include next_url even when absent |
API_DUMP_NULL_PREVIOUS_URL | True | Include previous_url even when absent |
API_DUMP_NULL_ERRORS | True | Always include errors |

